@@ -6,7 +6,7 @@ pub mod http_transport;
 pub(crate) mod nonce;
 pub(crate) mod replica_api;
 pub(crate) mod response;
-mod response_authentication;
+pub(crate) mod response_authentication;
 
 pub mod signed;
 pub mod status;
@@ -35,7 +35,8 @@ use status::Status;
 
 use crate::{
     agent::response_authentication::{
-        extract_der, initialize_bls, lookup_canister_info, lookup_request_status, lookup_value,
+        extract_der, initialize_bls, lookup_canister_info, lookup_canister_metadata,
+        lookup_request_status, lookup_value,
     },
     bls::bls12381::bls,
 };
@@ -597,7 +598,8 @@ impl Agent {
         })
     }
 
-    fn verify(&self, cert: &Certificate) -> Result<(), AgentError> {
+    /// Verify a certificate, checking delegation if present.
+    pub fn verify(&self, cert: &Certificate) -> Result<(), AgentError> {
         let sig = &cert.signature;
 
         let root_hash = cert.tree.digest();
@@ -649,6 +651,23 @@ impl Agent {
         lookup_canister_info(cert, canister_id, path)
     }
 
+    pub async fn read_state_canister_metadata(
+        &self,
+        canister_id: Principal,
+        path: &str,
+    ) -> Result<Vec<u8>, AgentError> {
+        let paths: Vec<Vec<Label>> = vec![vec![
+            "canister".into(),
+            canister_id.clone().into(),
+            "metadata".into(),
+            path.into(),
+        ]];
+
+        let cert = self.read_state_raw(paths, canister_id).await?;
+
+        lookup_canister_metadata(cert, canister_id, path)
+    }
+
     pub async fn request_status_raw(
         &self,
         request_id: &RequestId,
